RemoteFontCache class abstract

Stores font files by their SHA-256 (lowercase hex) across sessions.

The default keeps fonts in memory for the lifetime of the process. Implement this with a file or key-value store to persist them.

Implementers

Constructors

RemoteFontCache()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String hash) → Future<Uint8List?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String hash, Uint8List bytes) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited