RemoteFrame class
A frame: the app's logical size and the root of its chunk tree, whose chunks live in RemoteResources.chunks.
Constructors
- RemoteFrame(Size size, int root)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- root → int
-
Id of the chunk to draw, in RemoteResources.chunks.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
The app's size in logical pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited