RemoteKey class abstract final

Keys a viewer can press on the remote app. Text is sent separately.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

arrowLeft → const int
arrowRight → const int
back → const int
The system back action, like Android's back button.
backspace → const int
delete → const int
enter → const int
tab → const int