RemoteLog class
A line of output or an error reported by the remote app.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
Whether this is an uncaught error rather than printed output.
final
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time → DateTime
-
When the app logged it, on the device's clock.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited