logRevision property
Incremented whenever the log list changes, cheap to compare in widgets.
Implementation
final ValueNotifier<int> logRevision = ValueNotifier(0);
Incremented whenever the log list changes, cheap to compare in widgets.
final ValueNotifier<int> logRevision = ValueNotifier(0);