sendText method
Types text into the focused text field of the app.
Implementation
void sendText(String text) => _send(
ByteWriter()
..u8(MessageType.textInput)
..string(text),
);
Types text into the focused text field of the app.
void sendText(String text) => _send(
ByteWriter()
..u8(MessageType.textInput)
..string(text),
);