RemoteViewerStatus enum

Connection state of a RemoteViewerController.

Inheritance
Available extensions

Values

idle → const RemoteViewerStatus

Not connected.

connecting → const RemoteViewerStatus

Opening the connection to the relay.

waitingForDevice → const RemoteViewerStatus

Joined the session; the app has not sent its screen yet, or has left.

connected → const RemoteViewerStatus

Receiving the app's screen.

disconnected → const RemoteViewerStatus

The connection closed; see RemoteViewerController.error.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RemoteViewerStatus>
A constant List of the values in this enum, in order of their declaration.