RemoteFontCache class abstract
Stores font files by their SHA-256 (lowercase hex) across sessions.
The default keeps fonts in memory for the lifetime of the process. Implement this with a file or key-value store to persist them.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited