RemoteImage class
An uploaded image. It may have been downscaled by the host, so source rectangles from frames are mapped by scaleX/scaleY.
Constructors
- RemoteImage(Image image, int originalWidth, int originalHeight)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → Image
-
final
- originalHeight → int
-
final
- originalWidth → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleX → double
-
no setter
- scaleY → double
-
no setter
Methods
-
mapSource(
Rect src) → Rect -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited